module Pods
  class Pod
    attr_reader :name
    attr_reader :cidr
    attr_reader :availability_zones

    def initialize(data = {})
      load!(data.deep_symbolize_keys)
    end

    ##
    # Load details from a Podfile.
    def load(podfile_path)
      load!(YAML.load_file(podfile_path).deep_symbolize_keys)
    end

    def load!(data)
      @name = @data[:name].to_s.underscore
      @cidr = @data[:cidr]
      @availability_zones = @data[:availability_zones]
    end

    def availability_zones
       || []
    end

    def services
      @data[:services] || []
    end

    ##
    # Returns a cloudformation template for the Pod.
    def to_template
      template_path = File.expand_path(
        '../templates/cloudformation.template.erb',
        __FILE__
      )

      ERB.new(File.read(template_path)).result(binding)
    end

    def tags
      { pod: name }
    end

    private

    def _validate_data(data)
      # Raise an error if something is invalid.
    end
  end
end
